const fs = require('fs');
const sdk = require('matrix-js-sdk');
const spawn = require('child_process').spawn;
const yaml = require('js-yaml');

const config = yaml.safeLoad(fs.readFileSync('config.yaml'));

const matrixclient = sdk.createClient({
    baseUrl: config.baseurl,
    accessToken: config.accesstoken,
    userId: config.userid
});

// Autojoin for the bot (keep commented out when not needed to prevent abuse)
/*matrixclient.on('RoomMember.membership', function(event, member) {
    if(member.membership === 'invite' && member.userId === userid) {
        matrixclient.joinRoom(member.roomId).done(function() {
            console.log('Auto-joined %s', member.roomId);
        });
    }
});*/


const commands = {};

commands['rebuild'] = {};
commands['rebuild'].regex = /^!rebuild ([a-zA-Z0-9\-]*)$/;
commands['rebuild'].usage = '!rebuild <container>';
commands['rebuild'].exec = function(args, room, event) {
    let container = args[1];

    matrixclient.sendNotice(room.roomId, 'rebuilding container ' + container);
    console.log('sudo ./rebuild.sh ' + container);

    let script = spawn('/bin/bash', ['./rebuild.sh', container]);
    script.on('close', function(exitcode) {
        matrixclient.sendNotice(room.roomId, event.sender.userId + '\nrebuilt container ' + container + '\nexitcode: ' + exitcode);
    });
}


matrixclient.on('Room.timeline', function(event, room, resettimeline) {
    if(resettimeline) {
        return;
    }
    if(event.getType() !== 'm.room.message') {
        return;
    }

    let body = event.getContent().body;

    let bang = body.match(/^\!([a-zA-Z]*)/);
    if(bang === null) {
        return;
    }
    bang = bang[1];

    if(commands[bang] !== undefined) {
        let command = commands[bang];

        let args = body.match(command['regex']);
        if(args === null) {
            matrixclient.sendNotice(room.roomId, 'usage: ' + command.usage);
            return;
        }

        command.exec(args, room, event);
    }
});



matrixclient.startClient();
